Types for parsing the output of malloc_info from glibc.
A best effort was made to account for all edge cases in the XML output of malloc_info, but
there may be some cases that are not accounted for. If you find one, please open an issue.
Structs
- Aspace
- Arena space information
- Heap
- Arena-specific heap information
- Malloc
- Top-level type for all stats returned from
malloc_info - Sizes
- Wrapper type for sizes, which may be an array of XML elements
- System
- System memory information
- Total
- Total memory information
Enums
- Aspace
Type - Types of arena space
- Size
- Size information for an arena or the whole heap
- System
Type - Types of system memory
- Total
Type - Types of total memory